#! /bin/sh
$EXTRACTRC */*.kcfg >> rc.cpp || exit 11
$EXTRACTRC gui/*.rc >> rc.cpp || exit 12
$EXTRACTRC gui/*.ui >> rc.cpp || exit 13
$XGETTEXT *.cpp backend/*.cpp -o $podir/kbugbuster.pot
rm -f rc.cpp
